/********************************************************/
/*                                                      */
/* win2linux.h                                          */
/*                                                      */
/* conversions for portability                          */
/*                                                      */
/********************************************************/


#ifndef _LIB2DWIN2LINUX_H_
#define _LIB2DWIN2LINUX_H_

#include <glib.h>
#include <gdk/gdk.h>
#include <gdk/gdkx.h>
#include <GL/glx.h>
#include "x11/X/scolx.h"

#define CALLBACK
#define __cdecl
//#define __declspec dllexport






////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////
//                                                                                        //
//      Windows types to Linux (linux / X / gdk...) types                                 //
//                                                                                        //
////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////

typedef  GdkWindow* HWND;

typedef  GLXContext HGLRC;

typedef  guint UINT;

typedef  guint8 BYTE;
typedef  guint32 DWORD;
typedef  guint16 WORD;

typedef gint32  LONG;
typedef gint16 SHORT;

typedef gboolean boolean;



//Windows RGBTRIPLE type
typedef struct tagRGBTRIPLE
{
  BYTE rgbtBlue;
  BYTE rgbtGreen;
  BYTE rgbtRed;
} RGBTRIPLE;

#define SIZEOF_RGBTRIPLE 3


//Window RGBQUAD type
typedef struct tagRGBQUAD
{
  BYTE rgbBlue;
  BYTE rgbGreen;
  BYTE rgbRed;
  BYTE rgbReserved;
} RGBQUAD;

#define SIZEOF_RGBQUAD 4




// implementation of Windows BITMAPFILEHEADER type
typedef struct tagBITMAPFILEHEADER
{
  WORD  bfType;
  DWORD bfSize;
  WORD  bfReserved1;
  WORD  bfReserved2;
  DWORD bfOffBits;
} BITMAPFILEHEADER;

#define SIZEOF_BITMAPFILEHEADER 14



//implementation of Windows BITMAPINFOHEADER type
typedef struct tagBITMAPINFOHEADER
{
  LONG  biSize;
  LONG  biWidth;
  LONG  biHeight;
  SHORT biPlanes;
  SHORT biBitCount;
  LONG  biCompression;
  LONG  biSizeImage;
  LONG  biXPelsPerMeter;
  LONG  biYPelsPerMeter;
  LONG biClrUsed;
  LONG biClrImportant;
} BITMAPINFOHEADER;

#define SIZEOF_BITMAPINFOHEADER 40


//Windows constantes for biCompression field of BITMAPINFOHEADER struct
#define BI_RGB          0x00000000
#define BI_RLE8         0x00000001
#define BI_RLE4         0x00000002
#define BI_BITFIELDS    0x00000003



////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////
//                                                                                        //
//      Windows functions to Linux functions                                              //
//                                                                                        //
////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////

#define DestroyWindow(win) gdk_window_destroy((win))
#define SetParent(win,parent) gdk_window_reparent((win),(parent),0,0)
#define GetParent(win) gdk_window_get_parent((win))
#define MoveWindow(hwnd,x,y,w,h,boolparam) gdk_window_move_resize((hwnd), (x), (y), (w), (h))





////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////
//                                                                                        //
//      Windows OpenGL functions to Linux OpenGLX functions                               //
//                                                                                        //
////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////


#define wglMakeCurrent(win,glrc) glXMakeCurrent(scolX->dpy, GDK_WINDOW_XWINDOW((win)), (glrc))
#define wglMakeCurrentNULL() glXMakeCurrent(scolX->dpy, NULL, NULL)
#define wglDeleteContext(glrc)   glXDestroyContext(scolX->dpy, (glrc))
#define wglGetCurrentContext()  glXGetCurrentContext()
#define wglCreateContext(glrc)   glXCreateContext(scolX->dpy, scolGLX->GetVisualInfo(), (glrc), GL_TRUE)
#define SwapBuffers(hwnd) glXSwapBuffers(scolX->dpy, GDK_WINDOW_XWINDOW((hwnd)))




//$LB TODO : UNICODE
#define _istlead(p) FALSE
#define _tcsdec(lpszStart, lpsz) lpsz
#define _tcsinc(lpsz) lpsz

#define _istspace(car) ((car) == ' ')




typedef struct tagPOINT
{
  LONG x;
  LONG y;
} POINT;



  


#endif
